/*
 *	Copyright 1988 by Rayan S. Zachariassen, all rights reserved.
 *	This will be free software, but only when it is finished.
 */

#include "hostenv.h"
#include "mailer.h"
#include <fcntl.h>
#include "zmsignal.h"

/*
 * Reopen the log files, done at daemon startup, and when you want to roll over
 * the log files by doing a kill -HUP `cat .pid.router`.  The result of calling
 * this routine should be that stdout and stderr are attached to the same output
 * stream (for now anyway).
 * XX: possibly too much done inside a signal handler?
 */

int
loginit()
{
	extern char *log, *progname;
	int flags;

	if (log == NULL)
		return -1;
	fflush(stdout);
	rewind(stdout);
	fflush(stderr);
	rewind(stderr);
	if (freopen(log, "a+", stdout) != stdout
	    || dup2(FILENO(stdout), FILENO(stderr)) < 0) {	/* sigh */
		/* XX: stderr might be closed at this point... */
		fprintf(stderr, "%s: cannot open log: %s\n", progname, log);
		return -1;
	}
#if	defined(F_SETFL) && defined(O_APPEND)
	flags = fcntl(FILENO(stdout), F_GETFL, 0);
	flags |= O_APPEND;
	fcntl(FILENO(stdout), F_SETFL, flags);
#endif	/* F_SETFL */
	setvbuf(stdout, (char *)NULL, _IOLBF, 0);
	setvbuf(stderr, (char *)NULL, _IOLBF, 0);
	SIGNAL_HANDLE(SIGHUP, (RETSIGTYPE (*)()) loginit);
	return 0;
}
